*****************
Supported solvers
*****************

CVXOPT
======

.. autofunction:: qpsolvers.cvxopt_solve_qp

ECOS
====

.. autofunction:: qpsolvers.ecos_solve_qp

Gurobi
======

See the :ref:`installation page <gurobi-install>` for additional instructions
on installing this solver.

.. autofunction:: qpsolvers.gurobi_solve_qp

MOSEK
=====

.. autofunction:: qpsolvers.mosek_solve_qp

OSQP
====

.. autofunction:: qpsolvers.osqp_solve_qp

qpOASES
=======

See the :ref:`installation page <qpoases-install>` for additional instructions
on installing this solver.

.. autofunction:: qpsolvers.qpoases_solve_qp

quadprog
========

.. autofunction:: qpsolvers.quadprog_solve_qp
